
library(plm)
# library(splm)



data("Grunfeld", package="plm")
data("Gasoline", package="plm")
data("Produc", package="plm")


###############################
# data: Gasoline.dat
# example: 3.6.1

head(Grunfeld)

 grun.ols <- plm(inv ~ value + capital, data = Grunfeld, index = c("firm","year"), model = "pooling", effect = "twoways")
 grun.wit <- plm(inv ~ value + capital, data = Grunfeld, index = c("firm","year"), model = "within", effect = "twoways")
 grun.bIn <- plm(inv ~ value + capital, data = Grunfeld, model = "between", effect = "individual")
 grun.bTP <- plm(inv ~ value + capital, data = Grunfeld, model = "between", effect = "time")


 grun.swA <- plm(inv ~ value + capital, data = Grunfeld, index = c("firm","year"), model = "random", effect = "twoways", random.method = "swar" )
 grun.waH <- plm(inv ~ value + capital, data = Grunfeld, index = c("firm","year"), model = "random", effect = "twoways", random.method = "walhus")
 grun.ame <- plm(inv ~ value + capital, data = Grunfeld, index = c("firm","year"), model = "random", effect = "twoways", random.method = "amemiya")



# estimated parameters
rbind(
summary(grun.ols)$coef[,"Estimate"]
,
c(0, summary(grun.wit)$coef[,"Estimate"])
,
summary(grun.bIn)$coef[,"Estimate"]
,
summary(grun.bTP)$coef[,"Estimate"]
,
summary(grun.swA)$coef[,"Estimate"]
,
summary(grun.waH)$coef[,"Estimate"]
,
summary(grun.ame)$coef[,"Estimate"]
)[,-1]



# estimated standard errors of: remainder, individual, time-period
rbind(
sqrt( unlist(( summary(grun.swA)$ercomp)$sigma))
,
sqrt( unlist(( summary(grun.waH)$ercomp)$sigma))
,
sqrt( unlist(( summary(grun.ame)$ercomp)$sigma))
)



# estimated standard errors of parameters
rbind(
summary(grun.ols)$coef[,"Std. Error"]
,
c(0, summary(grun.wit)$coef[,"Std. Error"])
,
summary(grun.bIn)$coef[,"Std. Error"]
,
summary(grun.bTP)$coef[,"Std. Error"]
,
summary(grun.swA)$coef[,"Std. Error"]
,
summary(grun.waH)$coef[,"Std. Error"]
,
summary(grun.ame)$coef[,"Std. Error"]
)[,-1]


######################################

# data: Gasoline.dat
# example: 3.6.2


head(Gasoline)

# CO 'Country 1-18';
# YR 'Year 1960-1978';
# LGASPCAR 'LN(Gas/Car): The logarithm of motor gasoline consumption per auto';
# LINCOMEP 'LN(Y/N): The logarithm of real per-capita income';
# LRPMG    'LN(Pmg/Pgdp): The logarithm of real motor gasoline price';
# LCARPCAP 'LN(Car/N): The logarithm of the stock of cars per-capita';

 gas.ols <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, index = c("country","year"), model = "pooling", effect = "twoways")
 gas.wit <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, index = c("country","year"), model = "within", effect = "twoways")
 gas.bIn <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, model = "between", effect = "individual")
 gas.bTP <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, model = "between", effect = "time")


 gas.swA <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, index = c("country","year"), model = "random", effect = "twoways", random.method = "swar" )
 gas.waH <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, index = c("country","year"), model = "random", effect = "twoways", random.method = "walhus")
 gas.ame <- plm(lgaspcar ~ lincomep + lrpmg + lcarpcap, data = Gasoline, index = c("country","year"), model = "random", effect = "twoways", random.method = "amemiya")





# estimated parameters 
rbind(
summary(gas.ols)$coef[,"Estimate"]
,
c( 0, summary(gas.wit)$coef[,"Estimate"])
,
summary(gas.bIn)$coef[,"Estimate"]
,
summary(gas.bTP)$coef[,"Estimate"]
,
summary(gas.swA)$coef[,"Estimate"]
,
summary(gas.waH)$coef[,"Estimate"]
,
summary(gas.ame)$coef[,"Estimate"]
)[,-1]



# estimated standard errors of: remainder, individual, time-period
rbind(
sqrt( unlist(( summary(gas.swA)$ercomp)$sigma))
,
sqrt( unlist(( summary(gas.waH)$ercomp)$sigma))
,
sqrt( unlist(( summary(gas.ame)$ercomp)$sigma))
)




# estimated standard errors of parameters
rbind(
summary(gas.ols)$coef[,"Std. Error"]
,
c( 0, summary(gas.wit)$coef[,"Std. Error"])
,
summary(gas.bIn)$coef[,"Std. Error"]
,
summary(gas.bTP)$coef[,"Std. Error"]
,
summary(gas.swA)$coef[,"Std. Error"]
,
summary(gas.waH)$coef[,"Std. Error"]
,
summary(gas.ame)$coef[,"Std. Error"]
)[,-1]




varianta <- c( "ols", "wit", "bIn", "bTP", "swA", "waH", "ame")[5]
summary( eval(parse(text= paste( "gas", varianta, sep=".")) ))



##################################

# data: Produc.prn
# example: 3.6.3

head(Produc)


 prod.ols <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, index = c("state","year"), model = "pooling", effect = "twoways")
 prod.wit <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, index = c("state","year"), model = "within", effect = "twoways")
 prod.bIn <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, model = "between", effect = "individual")
 prod.bTP <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, model = "between", effect = "time")

 prod.swA <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, index = c("state","year"), model = "random", effect = "twoways", random.method = "swar" )
 prod.waH <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, index = c("state","year"), model = "random", effect = "twoways", random.method = "walhus")
 prod.ame <- plm( log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, index = c("state","year"), model = "random", effect = "twoways", random.method = "amemiya")




# estimated parameters
prod.est <- data.frame( cbind( rbind(
 summary(prod.ols)$coef[,"Estimate"]
,
c( 0, summary(prod.wit)$coef[,"Estimate"])
,
summary(prod.bIn)$coef[,"Estimate"]
,
summary(prod.bTP)$coef[,"Estimate"]
,
summary(prod.swA)$coef[,"Estimate"]
,
summary(prod.waH)$coef[,"Estimate"]
,
summary(prod.ame)$coef[,"Estimate"]
)[,-1], 
# estimated standard errors of: remainder, individual, time-period
rbind(
 rep(NA,3),  rep(NA,3), rep(NA,3),  rep(NA,3),
sqrt( unlist(( summary(prod.swA)$ercomp)$sigma))
,
sqrt( unlist(( summary(prod.waH)$ercomp)$sigma))
,
sqrt( unlist(( summary(prod.ame)$ercomp)$sigma))
)
))
row.names( prod.est) <- c( "ols", "wit", "bIn", "bTP", "swA", "waH", "ame")






# estimated standard errors of parameters
prod.ste <- data.frame( rbind(
 summary(prod.ols)$coef[,"Std. Error"]
,
c( 0, summary(prod.wit)$coef[,"Std. Error"])
,
summary(prod.bIn)$coef[,"Std. Error"]
,
summary(prod.bTP)$coef[,"Std. Error"]
,
summary(prod.swA)$coef[,"Std. Error"]
,
summary(prod.waH)$coef[,"Std. Error"]
,
summary(prod.ame)$coef[,"Std. Error"]
)[,-1] )
row.names( prod.ste) <- c( "ols", "wit", "bIn", "bTP", "swA", "waH", "ame")




summary(prod.ols)
summary(prod.wit)
summary(prod.bIn)
summary(prod.bTP)
summary(prod.swA)
summary(prod.waH)
summary(prod.ame)



#####################################
## table to latex format

library(xtable)


tab <- "prod.est"

print(
	xtable( eval( parse( text=(tab))), digits=3, align =
	 paste0( c("r|", rep("c", ncol(eval( parse( text=(tab)))))),collapse=""),
	 caption = paste0( "Estimated ", if( substr(tab, nchar(tab)-2, nchar(tab) ) == "est" ) "coefficients" else "std. errors", " from Produc data" ),
	label = paste0("tab:", tab)
	),
	 sanitize.text.function = identity, 
	 scalebox = 0.8,
	 file = paste0( tab ,".tex") )

 









